#[non_exhaustive]pub struct AuthorizationCodeLink {
pub uri: String,
pub scopes: Vec<String>,
pub client_id: String,
pub enable_pkce: bool,
/* private fields */
}Expand description
This configuration captures the details required to render an authorization link for the OAuth Authorization Code Flow.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.uri: StringThe base URI the user must click to trigger the authorization code login flow.
scopes: Vec<String>The scopes for which the user will authorize GCP Connectors on the connector data source.
client_id: StringThe client ID assigned to the GCP Connectors OAuth app for the connector data source.
enable_pkce: boolWhether to enable PKCE for the auth code flow.
Implementations
Sourceimpl AuthorizationCodeLink
impl AuthorizationCodeLink
pub fn new() -> Self
Sourcepub fn set_scopes<T, V>(self, v: T) -> Self
pub fn set_scopes<T, V>(self, v: T) -> Self
Sourcepub fn set_client_id<T: Into<String>>(self, v: T) -> Self
pub fn set_client_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_enable_pkce<T: Into<bool>>(self, v: T) -> Self
pub fn set_enable_pkce<T: Into<bool>>(self, v: T) -> Self
Sets the value of enable_pkce.
Example
ⓘ
let x = AuthorizationCodeLink::new().set_enable_pkce(true);Trait Implementations
Sourceimpl Clone for AuthorizationCodeLink
impl Clone for AuthorizationCodeLink
Sourcefn clone(&self) -> AuthorizationCodeLink
fn clone(&self) -> AuthorizationCodeLink
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AuthorizationCodeLink
impl Debug for AuthorizationCodeLink
Sourceimpl Default for AuthorizationCodeLink
impl Default for AuthorizationCodeLink
Sourcefn default() -> AuthorizationCodeLink
fn default() -> AuthorizationCodeLink
Returns the “default value” for a type. Read more
Sourceimpl Message for AuthorizationCodeLink
impl Message for AuthorizationCodeLink
Sourceimpl PartialEq for AuthorizationCodeLink
impl PartialEq for AuthorizationCodeLink
impl StructuralPartialEq for AuthorizationCodeLink