Connection

Struct Connection 

#[non_exhaustive]
pub struct Connection {
Show 18 fields pub name: String, pub create_time: Option<Timestamp>, pub update_time: Option<Timestamp>, pub labels: HashMap<String, String>, pub description: String, pub connector_version: String, pub status: Option<ConnectionStatus>, pub config_variables: Vec<ConfigVariable>, pub auth_config: Option<AuthConfig>, pub lock_config: Option<LockConfig>, pub destination_configs: Vec<DestinationConfig>, pub image_location: String, pub service_account: String, pub service_directory: String, pub envoy_image_location: String, pub suspended: bool, pub node_config: Option<NodeConfig>, pub ssl_config: Option<SslConfig>, /* private fields */
}
Connection represents an instance of connector.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: String

Output only. Resource name of the Connection. Format: projects/{project}/locations/{location}/connections/{connection}

create_time: Option<Timestamp>

Output only. Created time.

update_time: Option<Timestamp>

Output only. Updated time.

labels: HashMap<String, String>

Optional. Resource labels to represent user-provided metadata. Refer to cloud documentation on labels for more details. https://cloud.google.com/compute/docs/labeling-resources

description: String

Optional. Description of the resource.

connector_version: String

Required. Connector version on which the connection is created. The format is: projects//locations//providers//connectors//versions/* Only global location is supported for ConnectorVersion resource.

status: Option<ConnectionStatus>

Output only. Current status of the connection.

config_variables: Vec<ConfigVariable>

Optional. Configuration for configuring the connection with an external system.

auth_config: Option<AuthConfig>

Optional. Configuration for establishing the connection’s authentication with an external system.

lock_config: Option<LockConfig>

Optional. Configuration that indicates whether or not the Connection can be edited.

destination_configs: Vec<DestinationConfig>

Optional. Configuration of the Connector’s destination. Only accepted for Connectors that accepts user defined destination(s).

image_location: String

Output only. GCR location where the runtime image is stored. formatted like: gcr.io/{bucketName}/{imageName}

service_account: String

Optional. Service account needed for runtime plane to access GCP resources.

service_directory: String

Output only. The name of the Service Directory service name. Used for Private Harpoon to resolve the ILB address. e.g. “projects/cloud-connectors-e2e-testing/locations/us-central1/namespaces/istio-system/services/istio-ingressgateway-connectors”

envoy_image_location: String

Output only. GCR location where the envoy image is stored. formatted like: gcr.io/{bucketName}/{imageName}

suspended: bool

Optional. Suspended indicates if a user has suspended a connection or not.

node_config: Option<NodeConfig>

Optional. Node configuration for the connection.

ssl_config: Option<SslConfig>

Optional. Ssl config of a connection

Implementations

Source

impl Connection

pub fn new() -> Self

pub fn set_name<T: Into<String>>(self, v: T) -> Self

Sets the value of name.

Example
let x = Connection::new().set_name("example");
pub fn set_create_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of create_time.

Example
use wkt::Timestamp;
let x = Connection::new().set_create_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of create_time.

Example
use wkt::Timestamp;
let x = Connection::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = Connection::new().set_or_clear_create_time(None::<Timestamp>);
pub fn set_update_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of update_time.

Example
use wkt::Timestamp;
let x = Connection::new().set_update_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of update_time.

Example
use wkt::Timestamp;
let x = Connection::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = Connection::new().set_or_clear_update_time(None::<Timestamp>);
pub fn set_labels<T, K, V>(self, v: T) -> Self
where T: IntoIterator<Item = (K, V)>, K: Into<String>, V: Into<String>,

Sets the value of labels.

Example
let x = Connection::new().set_labels([
    ("key0", "abc"),
    ("key1", "xyz"),
]);
pub fn set_description<T: Into<String>>(self, v: T) -> Self

Sets the value of description.

Example
let x = Connection::new().set_description("example");
pub fn set_connector_version<T: Into<String>>(self, v: T) -> Self

Sets the value of connector_version.

Example
let x = Connection::new().set_connector_version("example");
pub fn set_status<T>(self, v: T) -> Self

Sets the value of status.

Example
use google_cloud_connectors_v1::model::ConnectionStatus;
let x = Connection::new().set_status(ConnectionStatus::default()/* use setters */);
pub fn set_or_clear_status<T>(self, v: Option<T>) -> Self

Sets or clears the value of status.

Example
use google_cloud_connectors_v1::model::ConnectionStatus;
let x = Connection::new().set_or_clear_status(Some(ConnectionStatus::default()/* use setters */));
let x = Connection::new().set_or_clear_status(None::<ConnectionStatus>);
pub fn set_config_variables<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<ConfigVariable>,

Sets the value of config_variables.

Example
use google_cloud_connectors_v1::model::ConfigVariable;
let x = Connection::new()
    .set_config_variables([
        ConfigVariable::default()/* use setters */,
        ConfigVariable::default()/* use (different) setters */,
    ]);
pub fn set_auth_config<T>(self, v: T) -> Self
where T: Into<AuthConfig>,

Sets the value of auth_config.

Example
use google_cloud_connectors_v1::model::AuthConfig;
let x = Connection::new().set_auth_config(AuthConfig::default()/* use setters */);
pub fn set_or_clear_auth_config<T>(self, v: Option<T>) -> Self
where T: Into<AuthConfig>,

Sets or clears the value of auth_config.

Example
use google_cloud_connectors_v1::model::AuthConfig;
let x = Connection::new().set_or_clear_auth_config(Some(AuthConfig::default()/* use setters */));
let x = Connection::new().set_or_clear_auth_config(None::<AuthConfig>);
pub fn set_lock_config<T>(self, v: T) -> Self
where T: Into<LockConfig>,

Sets the value of lock_config.

Example
use google_cloud_connectors_v1::model::LockConfig;
let x = Connection::new().set_lock_config(LockConfig::default()/* use setters */);
pub fn set_or_clear_lock_config<T>(self, v: Option<T>) -> Self
where T: Into<LockConfig>,

Sets or clears the value of lock_config.

Example
use google_cloud_connectors_v1::model::LockConfig;
let x = Connection::new().set_or_clear_lock_config(Some(LockConfig::default()/* use setters */));
let x = Connection::new().set_or_clear_lock_config(None::<LockConfig>);
pub fn set_destination_configs<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<DestinationConfig>,

Sets the value of destination_configs.

Example
use google_cloud_connectors_v1::model::DestinationConfig;
let x = Connection::new()
    .set_destination_configs([
        DestinationConfig::default()/* use setters */,
        DestinationConfig::default()/* use (different) setters */,
    ]);
pub fn set_image_location<T: Into<String>>(self, v: T) -> Self

Sets the value of image_location.

Example
let x = Connection::new().set_image_location("example");
pub fn set_service_account<T: Into<String>>(self, v: T) -> Self

Sets the value of service_account.

Example
let x = Connection::new().set_service_account("example");
pub fn set_service_directory<T: Into<String>>(self, v: T) -> Self

Sets the value of service_directory.

Example
let x = Connection::new().set_service_directory("example");
pub fn set_envoy_image_location<T: Into<String>>(self, v: T) -> Self

Sets the value of envoy_image_location.

Example
let x = Connection::new().set_envoy_image_location("example");
pub fn set_suspended<T: Into<bool>>(self, v: T) -> Self

Sets the value of suspended.

Example
let x = Connection::new().set_suspended(true);
pub fn set_node_config<T>(self, v: T) -> Self
where T: Into<NodeConfig>,

Sets the value of node_config.

Example
use google_cloud_connectors_v1::model::NodeConfig;
let x = Connection::new().set_node_config(NodeConfig::default()/* use setters */);
pub fn set_or_clear_node_config<T>(self, v: Option<T>) -> Self
where T: Into<NodeConfig>,

Sets or clears the value of node_config.

Example
use google_cloud_connectors_v1::model::NodeConfig;
let x = Connection::new().set_or_clear_node_config(Some(NodeConfig::default()/* use setters */));
let x = Connection::new().set_or_clear_node_config(None::<NodeConfig>);
pub fn set_ssl_config<T>(self, v: T) -> Self
where T: Into<SslConfig>,

Sets the value of ssl_config.

Example
use google_cloud_connectors_v1::model::SslConfig;
let x = Connection::new().set_ssl_config(SslConfig::default()/* use setters */);
pub fn set_or_clear_ssl_config<T>(self, v: Option<T>) -> Self
where T: Into<SslConfig>,

Sets or clears the value of ssl_config.

Example
use google_cloud_connectors_v1::model::SslConfig;
let x = Connection::new().set_or_clear_ssl_config(Some(SslConfig::default()/* use setters */));
let x = Connection::new().set_or_clear_ssl_config(None::<SslConfig>);