#[non_exhaustive]pub struct ConnectionSchemaMetadata {
pub entities: Vec<String>,
pub actions: Vec<String>,
pub name: String,
pub update_time: Option<Timestamp>,
pub refresh_time: Option<Timestamp>,
pub state: State,
/* private fields */
}Expand description
ConnectionSchemaMetadata is the singleton resource of each connection. It includes the entity and action names of runtime resources exposed by a connection backend.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.entities: Vec<String>Output only. List of entity names.
actions: Vec<String>Output only. List of actions.
name: StringOutput only. Resource name. Format: projects/{project}/locations/{location}/connections/{connection}/connectionSchemaMetadata
update_time: Option<Timestamp>Output only. Timestamp when the connection runtime schema was updated.
refresh_time: Option<Timestamp>Output only. Timestamp when the connection runtime schema refresh was triggered.
state: StateOutput only. The current state of runtime schema.
Implementations
Sourceimpl ConnectionSchemaMetadata
impl ConnectionSchemaMetadata
pub fn new() -> Self
Sourcepub fn set_entities<T, V>(self, v: T) -> Self
pub fn set_entities<T, V>(self, v: T) -> Self
Sourcepub fn set_actions<T, V>(self, v: T) -> Self
pub fn set_actions<T, V>(self, v: T) -> Self
Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
ⓘ
use wkt::Timestamp;
let x = ConnectionSchemaMetadata::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
ⓘ
use wkt::Timestamp;
let x = ConnectionSchemaMetadata::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = ConnectionSchemaMetadata::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_refresh_time<T>(self, v: T) -> Self
pub fn set_refresh_time<T>(self, v: T) -> Self
Sets the value of refresh_time.
Example
ⓘ
use wkt::Timestamp;
let x = ConnectionSchemaMetadata::new().set_refresh_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_refresh_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_refresh_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of refresh_time.
Example
ⓘ
use wkt::Timestamp;
let x = ConnectionSchemaMetadata::new().set_or_clear_refresh_time(Some(Timestamp::default()/* use setters */));
let x = ConnectionSchemaMetadata::new().set_or_clear_refresh_time(None::<Timestamp>);Trait Implementations
Sourceimpl Clone for ConnectionSchemaMetadata
impl Clone for ConnectionSchemaMetadata
Sourcefn clone(&self) -> ConnectionSchemaMetadata
fn clone(&self) -> ConnectionSchemaMetadata
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConnectionSchemaMetadata
impl Debug for ConnectionSchemaMetadata
Sourceimpl Default for ConnectionSchemaMetadata
impl Default for ConnectionSchemaMetadata
Sourcefn default() -> ConnectionSchemaMetadata
fn default() -> ConnectionSchemaMetadata
Returns the “default value” for a type. Read more
Sourceimpl Message for ConnectionSchemaMetadata
impl Message for ConnectionSchemaMetadata
Sourceimpl PartialEq for ConnectionSchemaMetadata
impl PartialEq for ConnectionSchemaMetadata
impl StructuralPartialEq for ConnectionSchemaMetadata