#[non_exhaustive]pub struct EgressControlConfig {
pub oneof_backends: Option<OneofBackends>,
/* private fields */
}Expand description
Egress control config for connector runtime. These configurations define the rules to identify which outbound domains/hosts needs to be whitelisted. It may be a static information for a particular connector version or it is derived from the configurations provided by the customer in Connection resource.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.oneof_backends: Option<OneofBackends>Implementations
Sourceimpl EgressControlConfig
impl EgressControlConfig
pub fn new() -> Self
Sourcepub fn set_oneof_backends<T: Into<Option<OneofBackends>>>(self, v: T) -> Self
pub fn set_oneof_backends<T: Into<Option<OneofBackends>>>(self, v: T) -> Self
Sets the value of oneof_backends.
Note that all the setters affecting oneof_backends are mutually
exclusive.
Example
use google_cloud_connectors_v1::model::egress_control_config::OneofBackends;
let x = EgressControlConfig::new().set_oneof_backends(Some(OneofBackends::Backends("example".to_string())));Sourcepub fn backends(&self) -> Option<&String>
pub fn backends(&self) -> Option<&String>
The value of oneof_backends
if it holds a Backends, None if the field is not set or
holds a different branch.
Sourcepub fn set_backends<T: Into<String>>(self, v: T) -> Self
pub fn set_backends<T: Into<String>>(self, v: T) -> Self
Sets the value of oneof_backends
to hold a Backends.
Note that all the setters affecting oneof_backends are
mutually exclusive.
Example
let x = EgressControlConfig::new().set_backends("example");
assert!(x.backends().is_some());
assert!(x.extraction_rules().is_none());Sourcepub fn extraction_rules(&self) -> Option<&Box<ExtractionRules>>
pub fn extraction_rules(&self) -> Option<&Box<ExtractionRules>>
The value of oneof_backends
if it holds a ExtractionRules, None if the field is not set or
holds a different branch.
Sourcepub fn set_extraction_rules<T: Into<Box<ExtractionRules>>>(self, v: T) -> Self
pub fn set_extraction_rules<T: Into<Box<ExtractionRules>>>(self, v: T) -> Self
Sets the value of oneof_backends
to hold a ExtractionRules.
Note that all the setters affecting oneof_backends are
mutually exclusive.
Example
use google_cloud_connectors_v1::model::ExtractionRules;
let x = EgressControlConfig::new().set_extraction_rules(ExtractionRules::default()/* use setters */);
assert!(x.extraction_rules().is_some());
assert!(x.backends().is_none());Trait Implementations
Sourceimpl Clone for EgressControlConfig
impl Clone for EgressControlConfig
Sourcefn clone(&self) -> EgressControlConfig
fn clone(&self) -> EgressControlConfig
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more