#[non_exhaustive]pub struct RuntimeConfig {
pub location_id: String,
pub connd_topic: String,
pub connd_subscription: String,
pub control_plane_topic: String,
pub control_plane_subscription: String,
pub runtime_endpoint: String,
pub state: State,
pub schema_gcs_bucket: String,
pub service_directory: String,
pub name: String,
/* private fields */
}Expand description
RuntimeConfig is the singleton resource of each location. It includes generic resource configs consumed by control plane and runtime plane like: pub/sub topic/subscription resource name, Cloud Storage location storing schema etc.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.location_id: StringOutput only. location_id of the runtime location. E.g. “us-west1”.
connd_topic: StringOutput only. Pub/Sub topic for connd to send message. E.g. projects/{project-id}/topics/{topic-id}
connd_subscription: StringOutput only. Pub/Sub subscription for connd to receive message. E.g. projects/{project-id}/subscriptions/{topic-id}
control_plane_topic: StringOutput only. Pub/Sub topic for control plne to send message. communication. E.g. projects/{project-id}/topics/{topic-id}
control_plane_subscription: StringOutput only. Pub/Sub subscription for control plane to receive message. E.g. projects/{project-id}/subscriptions/{topic-id}
runtime_endpoint: StringOutput only. The endpoint of the connectors runtime ingress.
state: StateOutput only. The state of the location.
schema_gcs_bucket: StringOutput only. The Cloud Storage bucket that stores connector’s schema reports.
service_directory: StringOutput only. The name of the Service Directory service name.
name: StringOutput only. Name of the runtimeConfig resource. Format: projects/{project}/locations/{location}/runtimeConfig
Implementations
Sourceimpl RuntimeConfig
impl RuntimeConfig
pub fn new() -> Self
Sourcepub fn set_location_id<T: Into<String>>(self, v: T) -> Self
pub fn set_location_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_connd_topic<T: Into<String>>(self, v: T) -> Self
pub fn set_connd_topic<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_connd_subscription<T: Into<String>>(self, v: T) -> Self
pub fn set_connd_subscription<T: Into<String>>(self, v: T) -> Self
Sets the value of connd_subscription.
Example
let x = RuntimeConfig::new().set_connd_subscription("example");Sourcepub fn set_control_plane_topic<T: Into<String>>(self, v: T) -> Self
pub fn set_control_plane_topic<T: Into<String>>(self, v: T) -> Self
Sets the value of control_plane_topic.
Example
let x = RuntimeConfig::new().set_control_plane_topic("example");Sourcepub fn set_control_plane_subscription<T: Into<String>>(self, v: T) -> Self
pub fn set_control_plane_subscription<T: Into<String>>(self, v: T) -> Self
Sets the value of control_plane_subscription.
Example
let x = RuntimeConfig::new().set_control_plane_subscription("example");Sourcepub fn set_runtime_endpoint<T: Into<String>>(self, v: T) -> Self
pub fn set_runtime_endpoint<T: Into<String>>(self, v: T) -> Self
Sets the value of runtime_endpoint.
Example
let x = RuntimeConfig::new().set_runtime_endpoint("example");Sourcepub fn set_schema_gcs_bucket<T: Into<String>>(self, v: T) -> Self
pub fn set_schema_gcs_bucket<T: Into<String>>(self, v: T) -> Self
Sets the value of schema_gcs_bucket.
Example
let x = RuntimeConfig::new().set_schema_gcs_bucket("example");Sourcepub fn set_service_directory<T: Into<String>>(self, v: T) -> Self
pub fn set_service_directory<T: Into<String>>(self, v: T) -> Self
Sets the value of service_directory.
Example
let x = RuntimeConfig::new().set_service_directory("example");Trait Implementations
Sourceimpl Clone for RuntimeConfig
impl Clone for RuntimeConfig
Sourcefn clone(&self) -> RuntimeConfig
fn clone(&self) -> RuntimeConfig
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more