#[non_exhaustive]pub struct SupportedRuntimeFeatures {
pub entity_apis: bool,
pub action_apis: bool,
pub sql_query: bool,
/* private fields */
}Expand description
Supported runtime features of a connector version. This is passed to the management layer to add a new connector version by the connector developer. Details about how this proto is passed to the management layer is covered in this doc - go/runtime-manifest.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.entity_apis: boolSpecifies if the connector supports entity apis like ‘createEntity’.
action_apis: boolSpecifies if the connector supports action apis like ‘executeAction’.
sql_query: boolSpecifies if the connector supports ‘ExecuteSqlQuery’ operation.
Implementations
Sourceimpl SupportedRuntimeFeatures
impl SupportedRuntimeFeatures
pub fn new() -> Self
Sourcepub fn set_entity_apis<T: Into<bool>>(self, v: T) -> Self
pub fn set_entity_apis<T: Into<bool>>(self, v: T) -> Self
Sets the value of entity_apis.
Example
ⓘ
let x = SupportedRuntimeFeatures::new().set_entity_apis(true);Sourcepub fn set_action_apis<T: Into<bool>>(self, v: T) -> Self
pub fn set_action_apis<T: Into<bool>>(self, v: T) -> Self
Sets the value of action_apis.
Example
ⓘ
let x = SupportedRuntimeFeatures::new().set_action_apis(true);Trait Implementations
Sourceimpl Clone for SupportedRuntimeFeatures
impl Clone for SupportedRuntimeFeatures
Sourcefn clone(&self) -> SupportedRuntimeFeatures
fn clone(&self) -> SupportedRuntimeFeatures
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SupportedRuntimeFeatures
impl Debug for SupportedRuntimeFeatures
Sourceimpl Default for SupportedRuntimeFeatures
impl Default for SupportedRuntimeFeatures
Sourcefn default() -> SupportedRuntimeFeatures
fn default() -> SupportedRuntimeFeatures
Returns the “default value” for a type. Read more
Sourceimpl Message for SupportedRuntimeFeatures
impl Message for SupportedRuntimeFeatures
Sourceimpl PartialEq for SupportedRuntimeFeatures
impl PartialEq for SupportedRuntimeFeatures
impl StructuralPartialEq for SupportedRuntimeFeatures